==> haskell-path-io-1.8.1-55-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path-io
version:              1.8.1
visibility:           public
id:                   path-io-1.8.1-CRQ01ElSOCOLHUk1qWr6EN
key:                  path-io-1.8.1-CRQ01ElSOCOLHUk1qWr6EN
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  004c1818a26bed6b1399304613fd27a3
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-9.2.8/site-local/path-io-1.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/path-io-1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path-io
hs-libraries:         HSpath-io-1.8.1-CRQ01ElSOCOLHUk1qWr6EN
depends:
    base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2
    dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4 filepath-1.4.2.2
    path-0.9.5-IRiljrQkWe5KvlpCrQH9Mz
    temporary-1.3-LhTJC0HpzSoAJPVdFavBZq time-1.11.1.1
    transformers-0.5.6.2 unix-compat-0.7.1-J1Kwi1oG5prLsIuHiVwF3d

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.8.1-66-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path-io
version:              1.8.1
visibility:           public
id:                   path-io-1.8.1-3foXXaCW7usKFvWdR9fpTJ
key:                  path-io-1.8.1-3foXXaCW7usKFvWdR9fpTJ
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  80323ec963a161310d00531a4f3eafd6
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-9.2.8/site-local/path-io-1.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/path-io-1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path-io
hs-libraries:         HSpath-io-1.8.1-3foXXaCW7usKFvWdR9fpTJ
depends:
    base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2
    dlist-1.0-LNr75TD4CZoKEEzkBmhWjA exceptions-0.10.4 filepath-1.4.2.2
    path-0.9.5-9124ykIABMXHDmnxFXSd3D
    temporary-1.3-92h1kCtCGR4FaQHxoGuxwh time-1.11.1.1
    transformers-0.5.6.2 unix-compat-0.7.2-3S8nQVag41zGjHM5MpRJPG

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
